dupin.detect
------------

.. rubric:: Overview

.. py:currentmodule:: dupin.detect

.. autosummary::
    :nosignatures:

    kneedle_elbow_detection
    CostLinearBiasedFit
    CostLinearFit
    SweepDetector
    two_pass_elbow_detection


.. rubric:: Details

.. automodule:: dupin.detect
    :synopsis: Methods and classes for change point detection.
    :members: kneedle_elbow_detection,
        CostLinearFit,
        CostLinearBiasedFit,
        SweepDetector,
        two_pass_elbow_detection
